@@ -48,7 +48,9 @@ where
     };
     n.visit_with(&mut v);
     let top_scope = v.scope;
-    v.data.top_scope().merge(top_scope, false);
+    v.data.top_scope().merge(top_scope.clone(), false);
+
+    v.data.scope(SyntaxContext::empty()).merge(top_scope, false);
 
     v.data
 }
@@ -138,6 +140,7 @@ pub(crate) enum ScopeKind {
 pub(crate) struct ScopeData {
     pub has_with_stmt: bool,
     pub has_eval_call: bool,
+    pub used_arguments: bool,
 }
 
 /// Analyzed info of a whole program we are working on.
@@ -218,6 +221,10 @@ where
     }
 
     fn report_usage(&mut self, i: &Ident, is_assign: bool) {
+        if i.sym == js_word!("arguments") {
+            self.scope.mark_used_arguments();
+        }
+
         self.data.report_usage(self.ctx, i, is_assign)
     }
 
@@ -253,9 +260,7 @@ where
 
             match &n.body {
                 BlockStmtOrExpr::BlockStmt(body) => {
-                    // We use visit_children_with instead of visit_with to bypass block scope
-                    // handler.
-                    body.visit_children_with(child);
+                    body.visit_with(child);
                 }
                 BlockStmtOrExpr::Expr(body) => {
                     body.visit_with(child);
