@@ -317,7 +317,13 @@ where
         {
             let _timer = timer!("apply pure optimize");
 
-            let mut visitor = pure_optimizer(self.options, self.marks, self.mode, self.pass >= 20);
+            let mut visitor = pure_optimizer(
+                self.options,
+                self.marks,
+                self.mode,
+                self.pass > 1,
+                self.pass >= 20,
+            );
             n.apply(&mut visitor);
             self.changed |= visitor.changed();
 
